@@ -7,7 +7,14 @@ from . import counter
 
 
 
+
+
 def nan_info(df : pd.DataFrame) -> pd.DataFrame:
+    '''
+    Get pandas.DataFrame with information about missing data in columns
+    Use case:
+    missing_info_df = Snaplib().nan_info(df)
+    '''
 
     if not isinstance(df, pd.core.frame.DataFrame):
         raise TypeError('The df must be a pandas.core.frame.DataFrame instance.')
@@ -26,6 +33,11 @@ def nan_info(df : pd.DataFrame) -> pd.DataFrame:
 
 
 def nan_plot(df : pd.DataFrame) -> plt.figure:
+    '''
+    Visualise missing data in pandas.DataFrame
+    Use case:
+    Snaplib().nan_plot(df)
+    '''
 
     if not isinstance(df, pd.core.frame.DataFrame):
         raise TypeError('The df must be a pandas.core.frame.DataFrame instance.')
@@ -44,6 +56,14 @@ def cleane( df : pd.DataFrame,
             target : str = None, 
             verbose : bool = True
             ) -> pd.DataFrame: 
+    '''
+    drop_duplicates
+    drop rows with nan in target
+    drop column with 1 unique value
+    Use case:
+    df = Snaplib().cleane(df, target_name, verbose=True)
+    '''
+    
 
     if not isinstance(df, pd.core.frame.DataFrame):
         raise TypeError('The df must be a pandas.core.frame.DataFrame instance.')
